@@ -280,21 +280,21 @@ void print_bigx(int x)
 
     y = get_pointer(x);		//get pointer of bigcell
     len = get_length(x);	//get length of bignum;
-    if (!bridge_flag)
+    if (!dialog_flag)
 	fprintf(GET_PORT(output_stream), "%d", bigcell[y]);
     else {
 	sprintf(str1, "%d", bigcell[y]);
-	strcat(bridge, str1);
+	strcat(output_buffer, str1);
     }
     y--;
     len--;
 
     do {
-	if (!bridge_flag)
+	if (!dialog_flag)
 	    fprintf(GET_PORT(output_stream), "%09d", bigcell[y]);
 	else {
 	    sprintf(str1, "%09d", bigcell[y]);
-	    strcat(bridge, str1);
+	    strcat(output_buffer, str1);
 	}
 	y--;
 	len--;
