@@ -1,6 +1,7 @@
 #include <stdlib.h>
 #include <math.h>
 #include <float.h>
+#include <string.h>
 #include "npl.h"
 
 void
@@ -13,8 +14,11 @@ defoperator(char *name, int (*func)(int, int, int), int weight, int spec,
 	atom = makeatom(name, OPE);
     else if (opt == 1)
 	atom = makeatom(name, SYS);
-    else
+    else {
 	atom = makeatom(name, USER);
+	if (strcmp(name, "|") == 0)
+	    virtical_flag = 1;
+    }
 
     old_spec = GET_OPT(atom);
     if (old_spec == FX ||
@@ -522,7 +526,7 @@ int eval(int x, int th)
 	if (eqp(x, makefunc("pi")))
 	    return (makeflt(3.14159265358979323846));
 	else if (eqlp(x, makefunc("random")))
-	    return (f_random(NIL, th));
+	    return (f_random(th));
 	else
 	    exception(NOT_NUM, eval_context, x, th);
     } else if (eqlp(car(x), makeatom("abs", FUNC))) {
@@ -1137,13 +1141,10 @@ int f_randi(int x, int th)
     return (makeint(rand() & x));
 }
 
-int f_random(int x, int th)
+int f_random(int th)
 {
     double d;
 
-    if (!nullp(x))
-	exception(WRONG_ARGS, makeind("random", 1, th), x, th);
-
     d = (double) rand() / RAND_MAX;
     return (makeflt(d));
 }
