@@ -344,9 +344,6 @@ gen_var_declare1(S,E) :-
 	write(arg),
     write(S),
     write(','),
-    write(targ),
-    write(S),
-    write(','),
     S1 is S+1,
     gen_var_declare1(S1,E).
 
@@ -427,8 +424,6 @@ gen_var_assign(S,E) :-
 gen_var_assign(S,E) :-
 	write(arg),
     write(S),
-    write(' = targ'),
-    write(S),
     write(' = Jnth(arglist,'),
     write(S),
     write(');\n'),
@@ -455,28 +450,6 @@ if( )... head
 ...
 */
 
-gen_tail_restore_args([],_).
-gen_tail_restore_args([A|As],N) :-
-    n_compiler_variable(A),
-    not(n_compiler_anonymous(A)),
-    write('Junify(targ'),write(N),write(',arg'),write(N),
-    write(',th);'),nl,
-    N1 is N+1,
-    gen_tail_restore_args(As,N1).
-gen_tail_restore_args([_|As],N) :-
-    N1 is N+1,
-    gen_tail_restore_args(As,N1).
-
-
-
-% clause sa tail recursive base
-gen_a_pred5((Head :- !),_) :-
-    optimize(tail),
-    gen_head(Head),
-    Head =.. [_|A],
-    gen_tail_restore_args(A,1),
-    write('return(Jexec_all(rest,Jget_sp(th),th));'),nl.
-
 % clause as tail recursive
 gen_a_pred5((Head :- Body),N) :-
     tail_body(Head,Body),
@@ -1664,10 +1637,10 @@ deterministic([],D,P,H,A) :-
     H == 1,
     A =:= D+P+H,!.
 deterministic([],D,P,H,A) :-
-    %write(user_output,D),write(user_output,P),write(user_output,H),write(user_output,A),
+    %write(user_output,D),write(user_output,P),write(user_output,H),write(user_output,A),nl,
     P == 0,
-    D == 1,
-    A =:= D+P+H,!.
+    D >= 1,!.
+    %A =:= D+P+H,!.
 deterministic(_,_,P,_,_) :-
     P > 1,
     !,fail.
@@ -1687,16 +1660,28 @@ deterministic([_|Cs],D,P,H,A) :-
 
 % arguments = [clauses],tail_count,pred_count, halt_base_count,all_count, arity
 tail_recursive([],T,P,H,A,_) :-
-    T > 0,
+    %write(user_output,T),write(user_output,P),write(user_output,H),write(user_output,A),nl,
+    T == 1,
+    P == 1,
+    A =:= T+P+H,!.
+tail_recursive([],T,P,H,A,_) :-
+    %write(user_output,T),write(user_output,P),write(user_output,H),write(user_output,A),nl,
+    T == 1,
     P == 0,
     H >= 1,
     A =:= T+P+H,!.
 tail_recursive(_,_,P,_,_,_) :-
+    %write(user_output,P),nl,
     P > 1,
     !,fail.
 tail_recursive([(_ :- !)|Cs],T,P,H,A,N) :-
     H1 is H+1,!,
     tail_recursive(Cs,T,P,H1,A,N).
+tail_recursive([(Head :- Body)|Cs],T,P,H,A,N) :-
+    not(tail_body(Head,Body)),
+    det_body(Head,Body,[]),
+    H1 is H+1,!,
+    tail_recursive(Cs,T,P,H1,A,N).
 tail_recursive([(Head :- Body)|Cs],T,P,H,A,N) :-
     independ(Head),
     butlast_body(Body,Body1),
@@ -1791,7 +1776,7 @@ halt_check([_|Cs],D,P,A) :-
 
 
 
-% deterministic body case. Each has cut or each is builtin or each is recur 
+% deterministic body case. Each has cut or each is builtin or each is tail-recur 
 % G is gournd_variable
 det_body(_,(_;_),_) :- fail.
 det_body(_,!,_).
@@ -1889,7 +1874,10 @@ gen_det_body((X,Y)) :-
 gen_det_body(X) :-
     gen_a_det_body(X),
     nl,
-    write('return(Jexec_all(rest,Jget_sp(th),th));').
+    write('return(Jexec_all(rest,Jget_sp(th),th));'),nl,
+    write('Jset_ac(save3,th);'),nl,
+    write('Junbind(save2,th);'),nl,
+    write('Jset_wp(save1,th);'),nl.
 
 gen_tail_body((X,Y),N) :-
     gen_a_det_body(X),
@@ -1960,7 +1948,7 @@ gen_a_det_body(X =< Y) :-
     eval_form(X),
     write(','),
     eval_form(Y),
-    write(') && Jinc_proof(th))').
+    write(') && Jinc_proof(th))'),nl.
 
 gen_a_det_body(X > Y) :-
     write('if(Jgreaterp('),
