@@ -1,6 +1,7 @@
 /* N-Prolog
 written by kenichi sasagawa 2016/9~
 */
+
 #include <setjmp.h>
 #include <stdio.h>
 #include <sys/ioctl.h>
@@ -16,13 +17,13 @@ address
  5,000,001 - 30,000,000  working area 
 30,000,001 - 32,000,000  variant area
 */
-#define VERSION     4.72
-#define CELLSIZE    30000000  // if raspberry PI set smaller size.
+#define VERSION     4.76
+//#define CELLSIZE    30000000  // if raspberry PI set smaller size.
 #define HEAPSIZE     5000000
 #define FREESIZE         500
 #define STACKSIZE    2000000
 #define VARIANTSIZE  2000000
-#define VARIANTMAX  CELLSIZE + VARIANTSIZE
+//#define VARIANTMAX  CELLSIZE + VARIANTSIZE
 #define BIGSIZE 20000000
 #define NTTBASE 1000
 #define RECORDMAX 12
@@ -36,8 +37,8 @@ address
 #define OPERATOR_NUMBER 24
 #define FUNCTION_NUMBER 22
 #define BUILTIN_NUMBER 220
-#define COMPILED_NUMBER 23
-#define EXTENDED_NUMBER 43
+#define COMPILED_NUMBER 10
+#define EXTENDED_NUMBER 53
 #define NIL         0
 #define YES         2
 #define NO          4
@@ -213,8 +214,9 @@ enum { GET_FLT_IDX,
 
 
 
-
-extern cell heap[CELLSIZE];
+extern cell *heap;
+extern int cell_size;
+extern int variant_max;
 extern int variant[VARIANTSIZE][THREADSIZE];
 extern int bigcell[BIGSIZE];
 extern int stack[STACKSIZE][THREADSIZE];
@@ -436,9 +438,9 @@ extern int fd_trace;
 #define SET_RECORD(addr,x)  heap[addr].val.car.record = x
 #define SET_SOCKET(addr,x)  heap[addr].val.car.socket = x
 #define SET_CURL(addr,x)    heap[addr].val.car.curl = x
-#define IS_INCELL(addr)     (addr >= 0 && addr < CELLSIZE)
-#define IS_OUTCELL(addr)    (addr < 0 || addr >= CELLSIZE)
-#define IS_ALPHA(addr)      (addr < VARIANTMAX && addr > CELLSIZE)
+int IS_INCELL(int addr);
+int IS_OUTCELL(int addr);
+int IS_ALPHA(int addr);
 #define IS_SINGLE(addr)     heap[addr].tag == SINGLE
 #define IS_BIGXNUM(addr)    heap[addr].tag == BIGX
 #define IS_LONGNUM(addr)    heap[addr].tag == LONGN
@@ -542,6 +544,7 @@ extern int ignore_flag;
 extern int link_flag;
 extern int listing_flag;
 extern int prefix_flag;
+extern int virtical_flag;
 extern int syntax_flag;
 extern int fileerr_flag;
 extern int exist_flag;
@@ -565,6 +568,7 @@ extern int dynamic_flag;
 extern int string_flag;
 extern int ifthenelse_false_flag;
 extern int compiled_flag;
+extern int compiler_flag;
 
 //------pointer----
 extern int hp; 
@@ -686,7 +690,6 @@ enum Error {
     NOT_COMPUTABLE,
     OUT_OF_RANGE,
     MALLOC_OVERF,
-    WRONG_ARGS,
     NOT_NUM,
     NOT_STR,
     NOT_LIST,
@@ -888,6 +891,16 @@ int b_flush_output(int arglist, int rest, int th);
 int b_format(int arglist, int rest, int th);
 int b_functor(int arglist, int rest, int th);
 int b_gbc(int arglist, int rest, int th);
+int b_gpio_init(int arglist, int rest, int th);
+int b_gpio_set_mode(int arglist, int rest, int th);
+int b_gpio_write(int arglist, int rest, int th);
+int b_gpio_read(int arglist, int rest, int th);
+int b_gpio_event_request(int arglist, int rest, int th);
+int b_gpio_event_wait(int arglist, int rest, int th);
+int b_gpio_event_read(int arglist, int rest, int th);
+int b_gpio_close(int arglist, int rest, int th);
+int b_sleep(int arglist, int rest, int th);
+int b_usleep(int arglist, int rest, int th);
 int b_n_generate_all_variable(int arglist, int rest, int th);
 int b_n_generate_variable(int arglist, int rest, int th);
 int b_get(int arglist, int rest, int th);
@@ -1148,7 +1161,7 @@ int f_exp(int x, int th);
 int f_ln(int x,int th);
 int f_log(int x,int th);
 int f_randi(int x,int th);
-int f_random(int x, int th);
+int f_random(int th);
 int findatom(int x, int property);
 int findvar(int sym, int th);
 int floatp(int x);
