@@ -50,7 +50,7 @@ int convert_to_variant(int x, int th)
 	var = GET_NAME(x);
 	substr = &var[2];
 	i = atoi(substr);
-	i = i + CELLSIZE;
+	i = i + cell_size;
 	return (i);
     }
     if (listp(x)) {
@@ -71,7 +71,7 @@ int convert_to_variable(int x, int th)
     if (nullp(x))
 	return (NIL);
     else if (IS_ALPHA(x)) {
-	sprintf(str, "V_%d", x - CELLSIZE);
+	sprintf(str, "V_%d", x - cell_size);
 	return (makevar(str));
     } else if (listp(x)) {
 	return (x);
@@ -632,7 +632,7 @@ int b_dp_and(int arglist, int rest, int th)
 	    i++;
 	}
 
-	
+
 	while (!all_received(result, m)) {
 	    if (ctrl_c_flag == 1) {
 		for (i = 0; i < m; i++) {
@@ -668,7 +668,7 @@ int b_dp_and(int arglist, int rest, int th)
 		    }
 		}
 	    }
-		usleep(1000);
+	    usleep(1000);
 	}
 	return (prove_all(rest, sp[th], th));
     }
@@ -701,7 +701,7 @@ int b_dp_or(int arglist, int rest, int th)
 	    i++;
 	}
 
-	
+
 	while (!all_received(result, m)) {
 	    if (ctrl_c_flag == 1) {
 		for (i = 0; i < m; i++) {
@@ -737,7 +737,7 @@ int b_dp_or(int arglist, int rest, int th)
 		    }
 		}
 	    }
-		usleep(1000);
+	    usleep(1000);
 	}
 	return (NO);
     }
@@ -931,8 +931,8 @@ int b_mt_create(int arglist, int rest, int th)
 	init_para();
 	m = thread_num + 1;
 	for (i = 0; i < m; i++) {
-	    wp_min[i] = HEAPSIZE + 1 + (CELLSIZE - HEAPSIZE) / m * i;
-	    wp_max[i] = wp_min[i] + (CELLSIZE - HEAPSIZE) / m;
+	    wp_min[i] = HEAPSIZE + 1 + (cell_size - HEAPSIZE) / m * i;
+	    wp_max[i] = wp_min[i] + (cell_size - HEAPSIZE) / m;
 	}
 	return (prove_all(rest, sp[th], th));
     }
@@ -1101,9 +1101,9 @@ void *preceiver(void *arg)
 	buffer[i] = 0;
 	strcpy(parent_buffer[n], buffer);
 
-	if(dp_trace){
-		printf("From child %d: %s", n, parent_buffer[n]);
-		fflush(stdout);
+	if (dp_trace) {
+	    printf("From child %d: %s", n, parent_buffer[n]);
+	    fflush(stdout);
 	}
     }
 
@@ -1148,7 +1148,7 @@ void *creceiver(void *arg)
 	    exception(SYSTEM_ERR, makestr("*creceiver"), NIL, 0);
 	}
 	//print_ascii(sub_buffer);
-	
+
 	strcat(buffer, sub_buffer);
 	if (sub_buffer[n - 1] != 0x16)
 	    goto reread;
