@@ -1380,7 +1380,10 @@ int readitem1(int th)
 	    return (temp);
 	}
     case VERTICAL:
-	return (makeatom("|", SIMP));
+	if (!virtical_flag)
+	    return (makeatom("|", SIMP));
+	else
+	    return (makeatom("|", USER));
     case INTEGER:
 	return (makeint(atoi(stok.buf)));
     case OCTNUM:
@@ -1418,9 +1421,12 @@ int readitem1(int th)
 	if (stok.type == LPAREN) {
 	    if (getatom(str, SYS, hash(str)))
 		temp = makeatom(str, SYS);
-	    else if (getatom(str, COMP, hash(str)))
-		temp = makeatom(str, COMP);
-	    else if (getatom(str, OPE, hash(str)))
+	    else if (getatom(str, COMP, hash(str))) {
+		if (compiler_flag)
+		    temp = makeatom(str, PRED);
+		else
+		    temp = makeatom(str, COMP);
+	    } else if (getatom(str, OPE, hash(str)))
 		temp = makeatom(str, OPE);
 	    else if (getatom(str, USER, hash(str)))
 		goto elseexit;
@@ -1483,7 +1489,7 @@ int readitem1(int th)
 	return (makeatom(stok.buf, ANOY));
     case VARIANT:
 	temp = atoi(stok.buf);
-	temp = temp + CELLSIZE;
+	temp = temp + cell_size;
 	return (temp);
     case STRING:
 	return (makestr(stok.buf));
