@@ -99,14 +99,18 @@ char extended[EXTENDED_NUMBER][30] = {
     { "existerrors" }, { "dp_create" }, { "dp_consult" }, { "dp_countup" },
     { "dp_transfer" }, { "dp_and" }, { "dp_or" }, { "dp_halt" },
     { "dp_reconsult" }, { "dp_setid" }, { "dp_senderr" },
-    { "dp_compile" }, { "dp_prove" }, { "dp_close" }, { "dp_trace" }, { "dp_notrace" },
+    { "dp_compile" }, { "dp_prove" }, { "dp_close" }, { "dp_trace" },
+    { "dp_notrace" },
     { "mt_create" }, { "mt_close" }, { "mt_and" }, { "mt_or" },
     { "mt_prove" }, { "cinline" }, { "check_file" }, { "cdeclare" },
     { "clibrary" },
+    { "gpio_init" }, { "gpio_set_mode" }, { "gpio_write" },
+    { "gpio_read" }, { "gpio_event_request" }, { "gpio_event_wait" },
+    { "gpio_event_read" },
+    { "gpio_close" }, { "sleep" }, { "usleep" },
     { "format" },
 };
 
-
 static bool in_operator_table(const char *str)
 {
     int i;
